@@ -1,5 +1,7 @@
 #! /bin/bash
 
+arch=`dpkg --print-architecture`
+
 last_by_version () {
 	local a="$1"
 	local b="$2"
@@ -12,7 +14,7 @@ last_by_version () {
 
 	shift 2
 
-	if dpkg --compare-versions `basename $a` gt `basename $b`; then
+	if dpkg --compare-versions `dpkg -f $a Version` gt `dpkg -f $b Version`; then
 		last_by_version $a $@
 	else
 		last_by_version $b $@
@@ -21,9 +23,11 @@ last_by_version () {
 
 make_paths() {
 #	set -x
-	exit=false
 	local PATHS=""
 	local i
+	local exit
+
+	exit=false
 
 	for i in $*; do
 		local f=""
@@ -31,20 +35,19 @@ make_paths() {
 		local j
 		for j in $archive/*/${i}_[^a-zA-Z]*.deb \
 				`pwd`/updates/${i}_[^a-zA-Z]*.deb; do
-			if [ -f $j ]; then
+			if [ -f "$j" ]; then
 				f="$f $j"
 			fi
 		done
 		p=`last_by_version $f`
-		if [ ! -f $p ]; then
-			echo "Can't find package" $p 1>& 2
+		if [ ! -f "$p" ]; then
+			echo "Can't find package" $i 1>& 2
 			exit=true
 		fi
 		PATHS=$PATHS" "$p
 	done
-	echo $PATHS
 	if $exit; then
 		exit -1
 	fi
+	echo $PATHS
 }
-
