@@ -1,7 +1,7 @@
 #! /bin/bash
 
 # Verbose shell execution.
-# set -x
+set -x
 
 revext="$1"
 kernel="$2"
@@ -10,6 +10,8 @@ packages_with_modules="$*"
 
 extractdir=/var/tmp/extract-tmp-$$
 
+kernel_version=`echo $kernel | sed -e 's/.*kernel-image-//' | \
+                        sed -e 's/_.*//'`
 rm -rf $extractdir
 mkdir $extractdir
 
@@ -23,6 +25,18 @@ if [ "$revext" = lowmem ]; then
 	rm -rf block ipv? misc net pcmcia fs *MODULES )
 fi
 
+# Tecra floppies won't have some scsi modules, as they don't fit on the
+# drivers disk.
+if [ "$revext" = tecra ]; then
+	(cd $extractdir/lib/modules/*/scsi; 
+	rm -rf 53c7,8xx.o AM53C974.o BusLogic.o NCR53c406a.o advansys.o \
+		aha152x.o aha1542.o aha1740.o aic7xxx.o dtc.o \
+		eata.o eata_dma.o eata_pio.o fdomain.o g_NCR5380.o gdth.o \
+		in2000.o megaraid.o ncr53c8xx.o pas16.o \
+		qlogicfas.o qlogicisp.o seagate.o t128.o tmscsim.o \
+		u14-34f.o ultrastor.o wd7000.o
+	)
+fi
 # creating modcont
 
 (cd $extractdir;
@@ -37,8 +51,14 @@ fi
 	done
 ) > modcont$revext
 
+# Adding the pcmcia-unconfigured
+# If this is changed, it should reflect any changes in 
+# utilities/dinstall/pcmcia.c
+if [ -d $extractdir/lib/modules/$kernel_version/pcmcia ]; then
+	touch $extractdir/lib/modules/$kernel_version/pcmcia/.unconfigured
+fi
+	
 # creating modules.tgz
-
 (cd $extractdir;tar clf - lib/modules|gzip -9) > modules$revext.tgz
 
 
