@@ -4,7 +4,7 @@
 #include <time.h>
 #include <stdio.h>
 
-const char			date_usage[] = "date";
+const char			date_usage[] = "date [+%s]";
 
 int
 date_main(struct FileInfo * i, int argc, char * * argv)
@@ -12,6 +12,9 @@ date_main(struct FileInfo * i, int argc, char * * argv)
 	time_t		t;
 
 	time(&t);
-	printf("%s\n", ctime(&t));
+	if (argc == 2)
+		printf("%ld\n", t);
+	else
+		printf("%s\n", ctime(&t));
 	return 0;
 }
