@@ -5,7 +5,11 @@ const char	update_usage[] = "update\n"
 "\n"
 "\tFlush buffered data to the disk devices every 30 seconds.\n";
 
+#if defined(__GLIBC__)
+#include <sys/kdaemon.h>
+#else
 _syscall2(int, bdflush, int, func, int, data);
+#endif /* __GLIBC__ */
 
 extern int
 update_main(struct FileInfo * i, int argc, char * * argv)
